![unimport](docs/assets/logo/unimport.png)

**A linter, formatter for finding and removing unused import statements.**

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/hakancelik96/unimport/master.svg)](https://results.pre-commit.ci/latest/github/hakancelik96/unimport/master)
![test](https://github.com/hakancelik96/unimport/workflows/Test/badge.svg)

[![Pypi](https://img.shields.io/pypi/v/unimport)](https://pypi.org/project/unimport/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/unimport)
[![Downloads](https://static.pepy.tech/personalized-badge/unimport?period=total&units=none&left_color=grey&right_color=red&left_text=downloads)](https://pepy.tech/project/unimport)
[![License](https://img.shields.io/github/license/hakancelik96/unimport.svg)](https://github.com/hakancelik96/unimport/blob/master/LICENSE)

[![Forks](https://img.shields.io/github/forks/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/fork)
[![Issues](https://img.shields.io/github/issues/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/issues)
[![Stars](https://img.shields.io/github/stars/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/stargazers)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/ad6385b18b524cf2b100aa646358b89f)](https://www.codacy.com/gh/hakancelik96/unimport/dashboard?utm_source=github.com&utm_medium=referral&utm_content=hakancelik96/unimport&utm_campaign=Badge_Grade)
[![Codecov](https://codecov.io/gh/hakancelik96/unimport/branch/master/graph/badge.svg)](https://codecov.io/gh/hakancelik96/unimport)
[![Contributors](https://img.shields.io/github/contributors/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/graphs/contributors)
[![Last Commit](https://img.shields.io/github/last-commit/hakancelik96/unimport.svg)](https://github.com/hakancelik96/unimport/commits/master)

For more information see: https://unimport.hakancelik.dev/
